@@ -53,14 +53,16 @@ Args:
 Model architectures:
   | Model                               | Params | FLOPs  | Input | Top1 Acc |
   | ----------------------------------- | ------ | ------ | ----- | -------- |
+  | CoAtNet0 (Self trained 105 epochs)  | 23.8M  | 2.17G  | 160   | 80.48    |
+  | - fine-tune 224, 37 epochs          | 23.8M  | 4.22G  | 224   | 82.21    |
   | CoAtNet0                            | 25M    | 4.2G   | 224   | 81.6     |
-  | CoAtNet0, Strided DConv             | 25M    | 4.6G   | 224   | 82.0     |
+  | CoAtNet0, Stride-2 DConv2D          | 25M    | 4.6G   | 224   | 82.0     |
   | CoAtNet0                            | 25M    | 13.4G  | 384   | 83.9     |
   | CoAtNet1                            | 42M    | 8.4G   | 224   | 83.3     |
-  | CoAtNet1, Strided DConv             | 42M    | 8.8G   | 224   | 83.5     |
+  | CoAtNet1, Stride-2 DConv2D          | 42M    | 8.8G   | 224   | 83.5     |
   | CoAtNet1                            | 42M    | 27.4G  | 384   | 85.1     |
   | CoAtNet2                            | 75M    | 15.7G  | 224   | 84.1     |
-  | CoAtNet2, Strided DConv             | 75M    | 16.6G  | 224   | 84.1     |
+  | CoAtNet2, Stride-2 DConv2D          | 75M    | 16.6G  | 224   | 84.1     |
   | CoAtNet2                            | 75M    | 49.8G  | 384   | 85.7     |
   | CoAtNet2                            | 75M    | 96.7G  | 512   | 85.9     |
   | CoAtNet2, ImageNet-21k pretrain     | 75M    | 16.6G  | 224   | 87.1     |
@@ -79,14 +81,14 @@ Model architectures:
 
   **JFT pre-trained models accuracy**
 
-  | Model    | Image resolution | Reported Params | self-defined Params | Top1 Acc |
-  | -------- | ---------------- | --------------- | ------------------- | -------- |
-  | CoAtNet3 | 384              | 168M            | 162.96M             | 88.52    |
-  | CoAtNet3 | 512              | 168M            | 163.57M             | 88.81    |
-  | CoAtNet4 | 512              | 275M            | 273.10M             | 89.11    |
-  | CoAtNet5 | 512              | 688M            | 680.47M             | 89.77    |
-  | CoAtNet6 | 512              | 1.47B           | 1.340B              | 90.45    |
-  | CoAtNet7 | 512              | 2.44B           | 2.422B              | 90.88    |
+  | Model                      | Input | Reported Params    | self-defined Params    | Top1 Acc |
+  | -------------------------- | ----- | ------------------ | ---------------------- | -------- |
+  | CoAtNet3, Stride-2 DConv2D | 384   | 168M, FLOPs 114G   | 160.64M, FLOPs 109.67G | 88.52    |
+  | CoAtNet3, Stride-2 DConv2D | 512   | 168M, FLOPs 214G   | 161.24M, FLOPs 205.06G | 88.81    |
+  | CoAtNet4                   | 512   | 275M, FLOPs 361G   | 270.69M, FLOPs 359.77G | 89.11    |
+  | CoAtNet5                   | 512   | 688M, FLOPs 812G   | 676.23M, FLOPs 807.06G | 89.77    |
+  | CoAtNet6                   | 512   | 1.47B, FLOPs 1521G | 1.336B, FLOPs 1470.56G | 90.45    |
+  | CoAtNet7                   | 512   | 2.44B, FLOPs 2586G | 2.413B, FLOPs 2537.56G | 90.88    |
 """
 
 CoAtNet0.__doc__ = __head_doc__ + """
