@@ -53,14 +53,19 @@ def multi_head_self_attention_channel(
     return attention_output
 
 
-def window_attention(inputs, window_size, num_heads=4, shift_size=0, name=""):
+def window_attention(inputs, window_size, num_heads=4, name=""):
     input_channel = inputs.shape[-1]
     window_height = window_size[0] if window_size[0] < inputs.shape[1] else inputs.shape[1]
     window_width = window_size[1] if window_size[1] < inputs.shape[2] else inputs.shape[2]
 
-    # window_partition, partition windows
-    patch_height, patch_width = inputs.shape[1] // window_height, inputs.shape[2] // window_width
-    # print(f">>>> patch_merging {inputs.shape = }, {patch_height = }, {patch_width = }, {window_height = }, {window_width = }")
+    # window_partition, partition windows, ceil mode
+    patch_height, patch_width = int(tf.math.ceil(inputs.shape[1] / window_height)), int(tf.math.ceil(inputs.shape[2] / window_width))
+    should_pad_hh, should_pad_ww = patch_height * window_height - inputs.shape[1], patch_width * window_width - inputs.shape[2]
+    # print(f">>>> window_attention {inputs.shape = }, {should_pad_hh = }, {should_pad_ww = }")
+    if should_pad_hh or should_pad_ww:
+        inputs = tf.pad(inputs, [[0, 0], [0, should_pad_hh], [0, should_pad_ww], [0, 0]])
+
+    # print(f">>>> window_attention {inputs.shape = }, {patch_height = }, {patch_width = }, {window_height = }, {window_width = }")
     # [batch * patch_height, window_height, patch_width, window_width * input_channel], limit transpose perm <= 4
     nn = tf.reshape(inputs, [-1, window_height, patch_width, window_width * input_channel])
     nn = tf.transpose(nn, [0, 2, 1, 3])  # [batch * patch_height, patch_width, window_height, window_width * input_channel]
@@ -73,6 +78,8 @@ def window_attention(inputs, window_size, num_heads=4, shift_size=0, name=""):
     nn = tf.reshape(nn, [-1, patch_width, window_height, window_width * input_channel])
     nn = tf.transpose(nn, [0, 2, 1, 3])  # [batch * patch_height, window_height, patch_width, window_width * input_channel]
     nn = tf.reshape(nn, [-1, patch_height * window_height, patch_width * window_width, input_channel])
+    if should_pad_hh or should_pad_ww:
+        nn = nn[:, : nn.shape[1] - should_pad_hh, : nn.shape[2] - should_pad_ww, :]  # In case should_pad_hh or should_pad_ww is 0
 
     return nn
 
@@ -114,8 +121,9 @@ def DaViT(
     num_blocks=[2, 2, 6, 2],
     out_channels=[96, 192, 384, 768],
     num_heads=[3, 6, 12, 24],
-    stem_width=96,
+    stem_width=-1,
     stem_patch_size=4,
+    # window_size=7,
     window_ratio=32,
     mlp_ratio=4,
     layer_scale=-1,
@@ -130,9 +138,12 @@ def DaViT(
 ):
     """ Patch stem """
     inputs = keras.layers.Input(input_shape)
+    stem_width = stem_width if stem_width > 0 else out_channels[0]
     nn = conv2d_no_bias(inputs, stem_width, kernel_size=7, strides=stem_patch_size, use_bias=True, padding="SAME", name="stem_")
     nn = layer_norm(nn, name="stem_")
-    window_size = [input_shape[0] // window_ratio, input_shape[1] // window_ratio]
+    # window_size = [input_shape[0] // window_ratio, input_shape[1] // window_ratio]
+    window_size = [int(tf.math.ceil(input_shape[0] / window_ratio)), int(tf.math.ceil(input_shape[1] / window_ratio))]
+    # window_size = window_size[:2] if isinstance(window_size, (list, tuple)) else [window_size, window_size]
 
     """ stages """
     total_blocks = sum(num_blocks)
@@ -140,8 +151,10 @@ def DaViT(
     for stack_id, (num_block, out_channel, num_head) in enumerate(zip(num_blocks, out_channels, num_heads)):
         stack_name = "stack{}_".format(stack_id + 1)
         if stack_id > 0:
-            nn = layer_norm(nn, name=stack_name + "downsample_")
-            nn = conv2d_no_bias(nn, out_channel, kernel_size=2, strides=2, use_bias=True, padding="VALID", name=stack_name + "downsample_")
+            ds_name = stack_name + "downsample_"
+            nn = layer_norm(nn, name=ds_name)
+            # Set use_torch_padding=False, as kernel_size == 2, otherwise shape will be enlarged by 1
+            nn = conv2d_no_bias(nn, out_channel, kernel_size=2, strides=2, use_bias=True, padding="SAME", use_torch_padding=False, name=ds_name)
         for block_id in range(num_block):
             block_name = stack_name + "block{}_".format(block_id + 1)
             block_drop_rate = drop_connect_rate * global_block_id / total_blocks
@@ -171,5 +184,25 @@ def DaViT_B(input_shape=(224, 224, 3), num_classes=1000, classifier_activation="
     num_blocks = [2, 2, 18, 2]
     out_channels = [128, 256, 512, 1024]
     num_heads = [4, 8, 16, 32]
-    stem_width = 128
     return DaViT(**locals(), model_name="davit_b", **kwargs)
+
+
+def DaViT_L(input_shape=(384, 384, 3), num_classes=1000, classifier_activation="softmax", pretrained=None, **kwargs):
+    num_blocks = [2, 2, 18, 2]
+    out_channels = [192, 384, 768, 1536]
+    num_heads = [6, 12, 24, 48]
+    return DaViT(**locals(), model_name="davit_l", **kwargs)
+
+
+def DaViT_H(input_shape=(512, 512, 3), num_classes=1000, classifier_activation="softmax", pretrained=None, **kwargs):
+    num_blocks = [2, 2, 18, 2]
+    out_channels = [256, 512, 1024, 2048]
+    num_heads = [8, 16, 32, 64]
+    return DaViT(**locals(), model_name="davit_h", **kwargs)
+
+
+def DaViT_G(input_shape=(512, 512, 3), num_classes=1000, classifier_activation="softmax", pretrained=None, **kwargs):
+    num_blocks = [2, 2, 24, 6]
+    out_channels = [384, 768, 1536, 3072]
+    num_heads = [12, 24, 48, 96]
+    return DaViT(**locals(), model_name="davit_g", **kwargs)
