@@ -28,13 +28,13 @@ def mlp_block(inputs, hidden_dim, output_channel=-1, drop_rate=0, use_conv=False
         nn = keras.layers.Conv2D(hidden_dim, kernel_size=1, use_bias=True, name=name and name + "Conv_0")(inputs)
     else:
         nn = keras.layers.Dense(hidden_dim, name=name and name + "Dense_0")(inputs)
-    nn = activation_by_name(nn, activation, name=name and name + activation)
-    nn = keras.layers.Dropout(drop_rate) if drop_rate > 0 else nn
+    nn = activation_by_name(nn, activation, name=name)
+    nn = keras.layers.Dropout(drop_rate)(nn) if drop_rate > 0 else nn
     if use_conv:
         nn = keras.layers.Conv2D(output_channel, kernel_size=1, use_bias=True, name=name and name + "Conv_1")(nn)
     else:
         nn = keras.layers.Dense(output_channel, name=name and name + "Dense_1")(nn)
-    nn = keras.layers.Dropout(drop_rate) if drop_rate > 0 else nn
+    nn = keras.layers.Dropout(drop_rate)(nn) if drop_rate > 0 else nn
     return nn
 
 
